@@ -4,7 +4,7 @@ import pickle
 import re
 
 from napari import Viewer
-from napari.layers import Image, Points
+from napari.layers import Points
 from napari.layers.utils.text import TextManager
 from pathlib import Path
 from qtpy.QtCore import QSettings
@@ -61,21 +61,26 @@ class Napping:
                     pre_transform_file_path=registration_dialog.pre_transform_path,
                     post_transform_file_path=registration_dialog.post_transform_path,
                 )
-            return self.load_dir(
-                self._to_matching_strategy(registration_dialog.matching_strategy),
-                registration_dialog.source_images_path,
-                registration_dialog.target_images_path,
-                registration_dialog.control_points_dest_path,
-                registration_dialog.transform_dest_path,
-                self._to_transform_type(registration_dialog.transform_type),
-                source_coords_dir_path=registration_dialog.source_coords_path,
-                transformed_coords_dest_dir_path=registration_dialog.transformed_coords_dest_path,
-                pre_transform_file_path=registration_dialog.pre_transform_path,
-                post_transform_file_path=registration_dialog.post_transform_path,
-                source_regex=registration_dialog.source_regex,
-                target_regex=registration_dialog.target_regex,
-                source_coords_regex=registration_dialog.source_coords_regex,
-            )
+            if registration_dialog.selection_mode == NappingDialog.SelectionMode.DIR:
+                registration_dialog.control_points_dest_path.mkdir(exist_ok=True)
+                registration_dialog.transform_dest_path.mkdir(exist_ok=True)
+                if registration_dialog.transformed_coords_dest_path is not None:
+                    registration_dialog.transformed_coords_dest_path.mkdir(exist_ok=True)
+                return self.load_dir(
+                    self._to_matching_strategy(registration_dialog.matching_strategy),
+                    registration_dialog.source_images_path,
+                    registration_dialog.target_images_path,
+                    registration_dialog.control_points_dest_path,
+                    registration_dialog.transform_dest_path,
+                    self._to_transform_type(registration_dialog.transform_type),
+                    source_coords_dir_path=registration_dialog.source_coords_path,
+                    transformed_coords_dest_dir_path=registration_dialog.transformed_coords_dest_path,
+                    pre_transform_file_path=registration_dialog.pre_transform_path,
+                    post_transform_file_path=registration_dialog.post_transform_path,
+                    source_regex=registration_dialog.source_regex,
+                    target_regex=registration_dialog.target_regex,
+                    source_coords_regex=registration_dialog.source_coords_regex,
+                )
         return False
 
     def load_file(
@@ -496,7 +501,6 @@ class Napping:
             self._controller = controller
             self._widget: Optional[NappingWidget] = None
             self._image_path: Optional[Path] = None
-            self._image_layers: List[Image] = []
             self._points_layer: Optional[Points] = None
 
         def initialize(self):
@@ -528,10 +532,6 @@ class Napping:
         def image_path(self) -> Optional[Path]:
             return self._image_path
 
-        @property
-        def image_layers(self) -> List[Image]:
-            return self._image_layers
-
         @property
         def points_layer(self) -> Optional[Points]:
             return self._points_layer
@@ -550,24 +550,27 @@ class Napping:
         def control_points(self, control_points: pd.DataFrame):
             if self._points_layer is None:
                 raise RuntimeError('points layer is None')
-            self._points_layer.data = control_points.values
+            with self._points_layer.events.current_properties.blocker():
+                self._points_layer.data = control_points.values
             properties = self._points_layer.properties
             properties['id'] = control_points.index.values
             self._points_layer.properties = properties
             self._points_layer_text_workaround()
+            self._points_layer.refresh()
             self._widget.refresh()
 
         def _open_image(self, path: Path):
             self._image_path = path
             try:
-                self._image_layers = self._viewer.open(str(path), layer_type='image') or []
+                self._viewer.open(str(path), layer_type='image')
             except:
-                self._image_layers = None
+                pass  # TODO https://github.com/napari/napari/issues/2201
 
         def _close_image(self):
             self._image_path = None
-            while len(self._image_layers) > 0:
-                self._viewer.layers.remove(self._image_layers.pop())
+            image_layers = [layer for layer in self._viewer.layers if layer != self._points_layer]
+            for image_layer in image_layers:
+                self._viewer.layers.remove(image_layer)
 
         def _add_points_layer(self):
             # noinspection PyUnresolvedReferences
